==> zio-aws-networkmanager_2.13-5.17.153.3-sources.jar: zio/aws/networkmanager/model/GetVpcAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetVpcAttachmentResponse(
    vpcAttachment: Option[zio.aws.networkmanager.model.VpcAttachment] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse = {
    import GetVpcAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
      .builder()
      .optionallyWith(vpcAttachment.map(value => value.buildAwsValue()))(
        _.vpcAttachment
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.GetVpcAttachmentResponse.wrap(buildAwsValue())
}
object GetVpcAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetVpcAttachmentResponse =
      zio.aws.networkmanager.model
        .GetVpcAttachmentResponse(vpcAttachment.map(value => value.asEditable))
    def vpcAttachment
        : Option[zio.aws.networkmanager.model.VpcAttachment.ReadOnly]
    def getVpcAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.VpcAttachment.ReadOnly
    ] = AwsError.unwrapOptionField("vpcAttachment", vpcAttachment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ) extends zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly {
    override val vpcAttachment
        : Option[zio.aws.networkmanager.model.VpcAttachment.ReadOnly] = scala
      .Option(impl.vpcAttachment())
      .map(value => zio.aws.networkmanager.model.VpcAttachment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ): zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-networkmanager_2.13-5.17.267.7-sources.jar: zio/aws/networkmanager/model/GetVpcAttachmentResponse.scala <==
package zio.aws.networkmanager.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetVpcAttachmentResponse(
    vpcAttachment: Optional[zio.aws.networkmanager.model.VpcAttachment] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse = {
    import GetVpcAttachmentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
      .builder()
      .optionallyWith(vpcAttachment.map(value => value.buildAwsValue()))(
        _.vpcAttachment
      )
      .build()
  }
  def asReadOnly
      : zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly =
    zio.aws.networkmanager.model.GetVpcAttachmentResponse.wrap(buildAwsValue())
}
object GetVpcAttachmentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.networkmanager.model.GetVpcAttachmentResponse =
      zio.aws.networkmanager.model
        .GetVpcAttachmentResponse(vpcAttachment.map(value => value.asEditable))
    def vpcAttachment
        : Optional[zio.aws.networkmanager.model.VpcAttachment.ReadOnly]
    def getVpcAttachment: ZIO[
      Any,
      AwsError,
      zio.aws.networkmanager.model.VpcAttachment.ReadOnly
    ] = AwsError.unwrapOptionField("vpcAttachment", vpcAttachment)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ) extends zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly {
    override val vpcAttachment
        : Optional[zio.aws.networkmanager.model.VpcAttachment.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.vpcAttachment())
        .map(value => zio.aws.networkmanager.model.VpcAttachment.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.networkmanager.model.GetVpcAttachmentResponse
  ): zio.aws.networkmanager.model.GetVpcAttachmentResponse.ReadOnly =
    new Wrapper(impl)
}
